@@ -1,15 +1,22 @@
 from django.contrib.auth.models import User
-from django.test import TestCase
+from django.db import IntegrityError
 
 from django_otp.oath import totp
+from django_otp.tests import TestCase
 
 
 class TestTwilioSMS(TestCase):
-    fixtures = ['tests/alice_and_bob']
-
     def setUp(self):
-        self.alice = User.objects.get(username='alice')
-        self.bob = User.objects.get(username='bob')
+        try:
+            self.alice = self.create_user('alice', 'password')
+            self.bob = self.create_user('bob', 'password')
+        except IntegrityError:
+            self.skipTest(u"Unable to create test users.")
+        else:
+            self.alice.twiliosmsdevice_set.create(number='test',
+                key='01234567890123456789')
+            self.bob.twiliosmsdevice_set.create(number='test',
+                key='98765432109876543210')
 
     def test_current(self):
         device = self.alice.twiliosmsdevice_set.get()
